@@ -1,8 +1,14 @@
-/* eslint-disable no-octal */
 // vim: expandtab:ts=2:sw=2
 
-const
-  tmp = require('../../lib/tmp');
+const tmp = require('../../lib/tmp');
+
+process.on('SIGINT', function () {
+  process.exit(0);
+});
+
+process.on('SIGTERM', function () {
+  process.exit(0);
+});
 
 // https://github.com/raszi/node-tmp/issues/121
 module.exports = function () {
